How can I contribute to streamparse?
------------------------------------
Thanks for your interest in contributing to streamparse. We think
you'll find the core maintainers great to work with and will help you along the
way when contributing pull requests.

If you already know what you'd like to add to streamparse then by all means,
feel free to submit a pull request and we'll review it.

If you're unsure about how to contribute, check out our `open issues`_ and find
one that looks interesting to you (we particularly need help on all issues
marked with the "help wanted" label).

If you're not sure how to start or have some questions, shoot us an email in
the `streamparse user group`_ and we'll give you a hand.

From there, get to work on your improvement and submit a pull request when ready which
we'll review.

.. _open issues: https://github.com/Parsely/streamparse/issues?state=open
.. _streamparse user group: https://groups.google.com/forum/#!forum/streamparse


Environment Setup
-----------------

Please see `Developing Streamparse <http://streamparse.readthedocs.io/en/master/develop.html>`_
in the docs for environment setup. Python and Leiningen are required.


Style Guidelines
----------------
We'll work with you to get pull requests merged into streamparse. But to help us out, generally
following PEP8 guidelines will result in less back and forth.

Parse.ly's CTO, Andrew Montalenti, has published on Github an `Elements of Python Style`_ with 
style suggestions for Python beyond PEP8.


.. _Elements of Python Style: https://github.com/amontalenti/elements-of-python-style


Contributor License Agreement
-----------------------------
No contributor license agreement is needed for streamparse. All pull requests are understood 
to be acceptable to release under streamparse's license, Apache 2.0.

